@@ -37,6 +37,7 @@ impl ValueEnum for Strictness {
       Strictness(M::Ast),
       Strictness(M::Relaxed),
       Strictness(M::Signature),
+      Strictness(M::Template),
     ]
   }
   fn to_possible_value(&self) -> Option<PossibleValue> {
@@ -49,6 +50,8 @@ impl ValueEnum for Strictness {
       M::Signature => {
         PossibleValue::new("signature").help("Match ast node except comments, without text")
       }
+      M::Template => PossibleValue::new("template")
+        .help("Similar to smart but match text only, node kinds are ignored"),
     })
   }
 }
