@@ -1,5 +1,4 @@
 #![cfg(test)]
-use ast_grep_core::source::TSParseError;
 
 use super::*;
 
@@ -25,23 +24,22 @@ fn test_cpp_pattern() {
   test_match("struct $A: $B", "struct A: B {}");
 }
 
-fn test_replace(src: &str, pattern: &str, replacer: &str) -> Result<String, TSParseError> {
+fn test_replace(src: &str, pattern: &str, replacer: &str) -> String {
   use crate::test::test_replace_lang;
   test_replace_lang(src, pattern, replacer, Cpp)
 }
 
 #[test]
-fn test_cpp_replace() -> Result<(), TSParseError> {
-  let ret = test_replace("expr->b()", "$A->b()", "func($A)->b()")?;
+fn test_cpp_replace() {
+  let ret = test_replace("expr->b()", "$A->b()", "func($A)->b()");
   assert_eq!(ret, "func(expr)->b()");
-  let ret = test_replace("if (a) { a;b;c; }", "if (a) { $$$A }", "$$$A")?;
+  let ret = test_replace("if (a) { a;b;c; }", "if (a) { $$$A }", "$$$A");
   assert_eq!(ret, "a;b;c;");
   // https://stackoverflow.com/questions/78663351
   let ret = test_replace(
     "if (a) { a;b;c; }",
     "if (a) { $$$VERYLONGNAME }",
     "$$$VERYLONGNAME",
-  )?;
+  );
   assert_eq!(ret, "a;b;c;");
-  Ok(())
 }
